/**
* @file Agenda.cpp
* @brief Declaraciones de todo lo necesario para trabajar con la clase Agenda
**/
#include <fstream>
#include <algorithm>
#include "Agenda.h"
#include "Utils.h"

Agenda::Agenda(std::string a_nombre_archivo) {
	nombre_archivo = a_nombre_archivo;
	std::ifstream archivo(nombre_archivo.c_str(),std::ios::binary|std::ios::ate);
	if (archivo.is_open()) {
		int tamanio_archivo = archivo.tellg();
		int cantidad_personas = tamanio_archivo/sizeof(registro_persona);
		arreglo.resize(cantidad_personas);
		archivo.seekg(0,std::ios::beg);
		for (int i=0;i<cantidad_personas;i++)
			arreglo[i].LeerDesdeBinario(archivo);
		archivo.close();
	}
}

bool Agenda::Guardar() {
	std::ofstream archivo(nombre_archivo.c_str(),std::ios::binary|std::ios::trunc);
	if (!archivo.is_open()) return false;
	int cantidad_personas = CantidadDatos();
	for (int i=0;i<cantidad_personas;i++)
		arreglo[i].GuardarEnBinario(archivo);
	archivo.close();
	return true;
}

Persona &Agenda::operator[](int i) {
	return arreglo[i];
}

Persona &Agenda::VerPersona(int i) {
	return arreglo[i];
}

int Agenda::CantidadDatos() {
	return arreglo.size();
}

void Agenda::AgregarPersona(const Persona &p) {
	arreglo.push_back(p);
}

// compara nombre y apellido, sin diferenciar maysculas y minsculas
int Agenda::BuscarApellidoYNombre(std::string parte, int pos_desde) {
	pasar_a_minusculas(parte);
	int cant = CantidadDatos();
	for (int i=pos_desde;i<cant;i++) {
		Persona &p = arreglo[i];
		std::string apenom = p.VerApellido()+", "+p.VerNombre();
		pasar_a_minusculas(apenom);
		if (apenom.find(parte,0)!=std::string::npos)
			return i;
	}
	return NO_SE_ENCUENTRA;
}

void Agenda::Ordenar(CriterioOrden criterio) {
	switch (criterio) {
	case ORDEN_APELLIDO_Y_NOMBRE: 
		sort(arreglo.begin(),arreglo.end(),criterio_comparacion_apellido_y_nombre); 
		break;
	case ORDEN_TELEFONO: 
		sort(arreglo.begin(),arreglo.end(),criterio_comparacion_telefono); 
		break;
	case ORDEN_DIRECCION: 
		sort(arreglo.begin(),arreglo.end(),criterio_comparacion_direccion); 
		break;
	case ORDEN_EMAIL: 
		sort(arreglo.begin(),arreglo.end(),criterio_comparacion_email); 
		break;
	};
}

void Agenda::EliminarPersona(int i) {
	arreglo.erase(arreglo.begin()+i);
}
